ComplexCPCCA
============

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexCPCCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexCPCCA.__init__
      ~ComplexCPCCA.components
      ~ComplexCPCCA.components_amplitude
      ~ComplexCPCCA.components_phase
      ~ComplexCPCCA.compute
      ~ComplexCPCCA.correlation_coefficients_X
      ~ComplexCPCCA.correlation_coefficients_Y
      ~ComplexCPCCA.cross_correlation_coefficients
      ~ComplexCPCCA.deserialize
      ~ComplexCPCCA.fit
      ~ComplexCPCCA.fraction_variance_X_explained_by_X
      ~ComplexCPCCA.fraction_variance_Y_explained_by_X
      ~ComplexCPCCA.fraction_variance_Y_explained_by_Y
      ~ComplexCPCCA.get_params
      ~ComplexCPCCA.get_serialization_attrs
      ~ComplexCPCCA.heterogeneous_patterns
      ~ComplexCPCCA.homogeneous_patterns
      ~ComplexCPCCA.inverse_transform
      ~ComplexCPCCA.load
      ~ComplexCPCCA.predict
      ~ComplexCPCCA.save
      ~ComplexCPCCA.scores
      ~ComplexCPCCA.scores_amplitude
      ~ComplexCPCCA.scores_phase
      ~ComplexCPCCA.serialize
      ~ComplexCPCCA.squared_covariance_fraction
      ~ComplexCPCCA.transform
   
   

   
   
   